==> kmess_1.4.2.orig.tar.gz: kmess-1.4.2/kmess/network/applications/mimeapplication.h <==
/***************************************************************************
                          mimeapplication.h -  description
                             -------------------
    begin                : Thu Nov 23 2004
    copyright            : (C) 2003 by Mike K. Bennett
                           (C) 2004 by Diederik van der Boor
    email                : vdboor --at-- codingdomain.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MIMEAPPLICATION_H
#define MIMEAPPLICATION_H

#include "application.h"

/**
 * Application framework class, implementing MSN4 Mime-style invitations.
 */
class MimeApplication : public Application
{
  Q_OBJECT

  public:
    // The constructor
                           MimeApplication(const QString& localIp);
    // The descructor
    virtual               ~MimeApplication();

    // Parse a received message (implements a pure virtual method)
    void                   gotMessage(const MimeMessage& message);

  protected:
    // Return the session ID, generating one if it doesn't exist
    const QString&         getSessionId();
    // Send a cancel message (implements a pure virtual method)
    void                   sendCancelMessage(const ApplicationCancelReason cancelReason);
    // Send a message to the contact
    void                   sendMessage(const MimeMessage& message);

  private: // Private methods
    // Generate a random session ID
    QString                generateSessionId() const;

  private: // Private attributes
    // A session ID
    QString                sessionId_;
};

#endif

==> kmess_1.5.orig.tar.gz: kmess-1.5/kmess/network/applications/mimeapplication.h <==
/***************************************************************************
                          mimeapplication.h -  description
                             -------------------
    begin                : Thu Nov 23 2004
    copyright            : (C) 2003 by Mike K. Bennett
                           (C) 2004 by Diederik van der Boor
    email                : vdboor --at-- codingdomain.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MIMEAPPLICATION_H
#define MIMEAPPLICATION_H

#include "application.h"

/**
 * The base class for all old-style (pre-msn6) invitations.
 * These invitations use plain text MIME messages to exchange the invitation data.
 * The incoming messages are passed to the gotMessage() method.
 * This method automatically calls the correct <code>contactStarted*</code>
 * and <code>userStarted*</code> methods.
 * These methods are implemented in each one of the derived classes.
 *
 * @author Mike K. Bennett, Diederik van der Boor
 * @ingroup Applications
 */
class MimeApplication : public Application
{
  Q_OBJECT

  public:
    // The constructor
                           MimeApplication(const QString &contactHandle);
    // The descructor
    virtual               ~MimeApplication();

    // Parse a received message (implements a pure virtual method)
    void                   gotMessage(const MimeMessage& message);

  protected:
    // Return the session ID, generating one if it doesn't exist
    const QString&         getSessionId();
    // Send a cancel message and terminate the application (implements a pure virtual method).
    void                   sendCancelMessage(const ApplicationCancelReason cancelReason);
    // Send a message to the contact
    void                   sendMessage(const MimeMessage& message);

  private: // Private methods
    // Generate a random session ID
    QString                generateSessionId() const;

  private: // Private attributes
    // A session ID
    QString                sessionId_;

  signals:
    // Give the ApplicationList a message to send to the server.
    void                   putMsg(const MimeApplication *source, const MimeMessage &message);
};

#endif
